import six

# if six.PY2:
#     __import__('pkg_resources').declare_namespace(__name__)

__author__ = """Ranger Huang"""
__email__ = 'ranger_huang@yeah.net'
__version__ = '0.2.0'
VERSION = __version__.split('.')



# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals

from wangdiantong.api.goods import GoodsAPI
from wangdiantong.api.logistics import LogisticsAPI
from wangdiantong.api.order import OrderAPI
from wangdiantong.api.stocks import StocksAPI
from wangdiantong.client.base import BaseAPIClient
from wangdiantong import settings


class OpenApiClient(BaseAPIClient):
    """ OpenApi 客户端

    """

    API_BASE_URL = settings.API_BASE_URL

    logistics = LogisticsAPI()

    stocks = StocksAPI()

    orders = OrderAPI()

    goods = GoodsAPI()


# -*- coding: utf-8 -*-
import os

API_BASE_URL = os.environ.get('WANGDIANTONG_HOST', 'http://121.41.177.115')

APPSECRET = os.environ.get('WANGDIANTONG_APPSECRET', 'CHANGE-ME')

APPKEY = os.environ.get('WANGDIANTONG_APPKEY', 'CHANGE-ME')

SID = os.environ.get('WANGDIANTONG_SID', 'CHANGE-ME')

SHOP_NO = os.environ.get('WANGDIANTONG_SHOP_NO', 'CHANGE-ME')

PLATFORM_ID = os.environ.get('WANGDIANTONG_PLATFORM_ID', 'CHANGE-ME')

WAREHOUSE_NO = os.environ.get('WANGDIANTONG_WAREHOUSE_NO', 'CHANGE-ME')




# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals

import datetime
import json

from wangdiantong.api.base import BaseAPIEndpoint


class OrderStatus(object):
    """
    0    所有订单
    5    已取消
    10   待付款
    15   等未付
    16   延时审核
    19   预订单前处理
    20   前处理
    21   委外前处理
    22   抢单前处理
    25   预订单
    27   待抢单
    30   待客审
    35   待财审
    40   待递交仓库
    45   递交仓库中
    50   已递交仓库
    53   未确认
    55   已审核
    95   已发货
    100  已签收
    105  部分打款
    110  已完成
    """


class OrderAPI(BaseAPIEndpoint):
    """
    Order

    Docs:
        https://open.wangdian.cn/qyb/open/apidoc/doc?path=trade_push.php
    """

    """
    接口名称	接口功能描述	接口简称	ERP功能界面的操作路径
    stockin_refund_push.php	创建ERP销售退货入库单	创建销售退货入库单	库存-》入库管理-》退货入库单管理界面
    stockin_order_query_refund.php	查询ERP中退换入库单信息	查询退换入库单	库存-》入库管理-》退货入库单管理界面
    trade_push.php	订单推送到ERP系统中；更新ERP原始订单信息	创建原始订单	订单-》原始订单界面）
    trade_query.php	查询ERP中系统订单	查询系统订单	订单-》订单管理界面
    logistics_sync_query.php	将erp中已发货的处于等待同步的订单抓取到进行物流同步	查询物流同步	订单-》物流同步界面
    logistics_sync_ack.php	将同步的结果回传到erp系统，系统会更新物流同步状态	物流同步状态回写	
    api_goods_stock_change_query.php	查询出ERP中库存发生了变化，此时平台和ERP的库存不一致的货品库存，然后去修改平台上的货品库存	查询库存同步	设置-》策略设置-》库存同步
    api_goods_stock_change_ack.php	将同步结果回传到ERP系统，这样下次再查询库存的时候，就不会再把这次已经库存同步了的货品查出来。	平台货品库存同步状态回写	
    sales_refund_push.php	已经发货的订单，如果退款或退货，需要调用该接口 创建原始退款单	创建原始退款单	订单-》原始退款单
    refund_query.php	查询ERP中退货或者换货的订单信息	查询退换管理	订单-》退换管理界面
    """

    def trade_query(self,
                    start_time, end_time, status=0,
                    page_no=0, page_size=10,
                    **kwargs): # type: (datetime.datetime, datetime.datetime, int, int, int)->dict
        """
        查询ERP中系统订单
              openapi:  /openapi2/trade_query.php
            奇门云网关:  method=wdt.trade.query

        Docs: https://open.wangdian.cn/qyb/open/apidoc/doc?path=trade_query.php

        :param datetime start_time: str datetime.strftime("%Y-%m-%d %H:%M:%S"), required 最后更新时间，开始日期
        :param datetime end_time: str datetime.strftime("%Y-%m-%d %H:%M:%S"), required  最后更新时间，结束日期
        :param int status: int(4), required 订单状态
        :param int page_no: int(10), required 页号,默认0，从0页开始
        :param int page_size: int(10), required 分页大小（最大不超过40条，默认返回40条）

        ::kwargs
        :param int img_url: int[0,1] 是否返回图片
        :param str trade_no: varchar(40) 订单编号
        :param str shop_no: varchar(40)	店铺编号		店铺编号
        :param str warehouse_no: varchar(40) 仓库编号
        :param int goodstax: int[0,1] 使用税率, 0 使用订单中的税率 1使用单品中的税率(默认0)
        :param int has_logistics_no: int[0,1] 物流单号限制, 0 没有任何限制(默认值) 1 物流单号不为空才返回 2 只返回物流单号为空的
        :param int src: int[0,1] 是否返回交易流水号, 1 返回订单的交易流水单号 0 不返回（默认值）
        :param str logistics_no: varchar(40) 物流单号

        :return:
        """
        query = dict(
            start_time=start_time.strftime("%Y-%m-%d %H:%M:%S"),
            end_time=end_time.strftime("%Y-%m-%d %H:%M:%S"),
            page_no=page_no,
            status=status,
            page_size=page_size,
        )
        query.update(**kwargs)
        data = dict(list(filter(lambda x: x[1] is not None, query.items())))
        return self._post("/openapi2/trade_query.php", data=data)

    def trade_push(self,
                   shop_no, trade_list, switch=1):
        """
        推送订单

        Docs: https://open.wangdian.cn/qyb/open/apidoc/doc?path=trade_push.php

        :param shop_no:
        :param trade_list:
        :param switch:
        :return:
        """
        data = {
            "shop_no": shop_no,
            "trade_list": json.dumps(trade_list),
            "switch": switch
        }
        return self._post("/openapi2/trade_push.php", data=data)



# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals

import copy
import inspect
import logging
import time

import requests

from wangdiantong.settings import API_BASE_URL
from wangdiantong.api.base import BaseAPIEndpoint
from wangdiantong.utils import calculate_signature

logger = logging.getLogger(__name__)


def _is_api_endpoint(obj):
    return isinstance(obj, BaseAPIEndpoint)


class Code(object):
    SUCCESS = 0


class Signer(object):

    def __init__(self, sid, appkey, appsecret):
        self.sid = sid
        self.appkey = appkey
        self.appsecret = appsecret

    def sign_data(self, request, timestamp=None):
        timestamp = timestamp or int(time.time())
        params = copy.deepcopy(request)
        params.update(
            sid=self.sid,
            appkey=self.appkey,
            timestamp=timestamp,
        )
        return calculate_signature(params, appsecret=self.appsecret), params

    def sign_request(self, request=None, timestamp=None):
        request = request or dict()
        signed_str, request = self.sign_data(request, timestamp)
        request.update(
            sign=signed_str
        )
        return request


class BaseAPIClient(object):
    logger = logger

    API_BASE_URL = API_BASE_URL

    CODE = Code

    NOW = None

    SIGNER_CLASS = Signer

    def __new__(cls, *args, **kwargs):
        self = super(BaseAPIClient, cls).__new__(cls)
        api_endpoints = inspect.getmembers(self, _is_api_endpoint)
        for name, _api in api_endpoints:
            api_cls = type(_api)
            _api = api_cls(self)
            setattr(self, name, _api)
        return self

    def __init__(self, sid, appkey, appsecret):
        self.signer = self.SIGNER_CLASS(sid=sid,
                                        appkey=appkey,
                                        appsecret=appsecret)

    def _sign_request(self, data):
        return self.signer.sign_request(request=data, timestamp=self.NOW)

    def _request(self, method, url_or_endpoint, data=None, headers=None,
                 **kwargs):
        if not url_or_endpoint.startswith(('http://', 'https://')):
            api_base_url = kwargs.pop('api_base_url', self.API_BASE_URL)
            uri = '{base}{endpoint}'.format(
                base=api_base_url,
                endpoint=url_or_endpoint
            )
        else:
            uri = url_or_endpoint

        headers = headers or {
            'Content-Type': 'application/x-www-form-urlencoded'
        }
        reqdata = self._sign_request(data=data)
        method = getattr(requests, method.lower())
        resp = method(uri, data=reqdata, headers=headers)

        try:
            data = resp.json()
        except:
            logger.debug('result parsing error', exc_info=True)
            raise
        data['code'] = int(data['code'])
        return data

    def get(self, url, **kwargs):
        return self._request(
            method='get',
            url_or_endpoint=url,
            **kwargs
        )

    def post(self, url, **kwargs):
        return self._request(
            method='post',
            url_or_endpoint=url,
            **kwargs
        )



# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals


class BaseAPIEndpoint(object):

    def __init__(self,
                 client=None):  # type: (wangdiantong.client.base.BaseAPIClient) -> None
        self._client = client

    def _get(self, url, **kwargs):
        if getattr(self, 'API_BASE_URL', None):
            kwargs['api_base_url'] = self.API_BASE_URL
        return self._client.get(url, **kwargs)

    def _post(self, url, **kwargs):
        if getattr(self, 'API_BASE_URL', None):
            kwargs['api_base_url'] = self.API_BASE_URL
        return self._client.post(url, **kwargs)

    @property
    def appkey(self):
        return self._client.signer.appkey

    @property
    def sid(self):
        return self._client.signer.sid

    @property
    def appsecret(self):
        return self._client.signer.appsecret



# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
import json

from wangdiantong.api.base import BaseAPIEndpoint


class LogisticsAPI(BaseAPIEndpoint):
    """ Logistics
        Docs:
            https://open.wangdian.cn/qyb/open/apidoc/doc
    """

    def sync_query(self, shop_no, limit, is_part_sync_able=None):
        """
        查询物流同步

        Docs:
            https://open.wangdian.cn/qyb/open/apidoc/doc?path=logistics_sync_query.php

        :param str shop_no: varchar(20) required 店铺编号
        :param int limit: int(4) 最多返回条数
        :param int is_part_sync_able: int(4)  是否支持拆单发货
        :return:
        """
        data = dict(
            shop_no=shop_no,
            limit=limit
        )
        if is_part_sync_able is not None:
            data['is_part_sync_able'] = is_part_sync_able
        return self._post("/openapi2/logistics_sync_query.php", data=data)

    def sync_ack(self, logistics_list):
        """
        物流同步状态回写(批量)

        Docs:
            https://open.wangdian.cn/qyb/open/apidoc/doc?path=logistics_sync_ack.php

        :param list logistics_list: [dict(rec_id=1, status=0, message="同步成功", )] 物流同步状态回传列表
        :return:
        """
        data = dict(
            logistics_list=json.dumps(logistics_list)
        )
        return self._post("/openapi2/logistics_sync_ack.php", data=data)

    ACK_SUCCESS = 0
    ACK_SUCCESS_MESSAGE = "同步成功"
    ACK_FAILURE = 1

    def item_for_ack(self, rec_id,
                     status=ACK_SUCCESS, message=ACK_SUCCESS_MESSAGE):
        return dict(
            rec_id=rec_id,
            status=status,
            message=message,
        )


# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
import datetime
import json

from wangdiantong.api.base import BaseAPIEndpoint


class StocksAPI(BaseAPIEndpoint):
    """ Goods Stocks

    Docs:
        https://open.wangdian.cn/qyb/open/apidoc/doc
    """

    def change_query(self, shop_no, limit):
        """
        查询库存同步

        Docs:
            https://open.wangdian.cn/qyb/open/apidoc/doc?path=api_goods_stock_change_query.php

        :param str shop_no: varchar(20) required 店铺编号
        :param int limit: int(4) 最多返回条数
        :return:
        """
        data = dict(
            shop_no=shop_no,
            limit=limit
        )
        import json
        data_json = json.dumps(data)
        assert data_json
        return self._post("/openapi2/api_goods_stock_change_query.php", data=data)

    def sync_ack(self,  stock_sync_list):
        """
        平台货品库存同步状态回写

        Docs:
            https://open.wangdian.cn/qyb/open/apidoc/doc?path=api_goods_stock_change_ack.php

        :param list stock_sync_list: [dict(rec_id=1, sync_stoc=100, stock_change_count=5634245)]
        :return:
        """
        data = dict(
            stock_sync_list=json.dumps(stock_sync_list)
        )
        return self._post("/openapi2/api_goods_stock_change_ack.php", data=data)

    def item_for_ack(self, rec_id, sync_stock, stock_change_count):
        """
        sync_ack 请求参数 stock_sync_list的元素

        :param int rec_id: int(11) required Erp内平台货品表主键id
        :param int sync_stock: int(11) required 货品库存
        :param int stock_change_count: int(11) required 库存变化时自增
        :return:
        """
        return dict(
            rec_id=rec_id,
            sync_stock=sync_stock,
            stock_change_count=stock_change_count
        )

    def query(self, start_time, end_time,
              warehouse_no=None, spec_no=None,
              page_no=0, page_size=40): # type: (datetime.datetime, datetime.datetime, int, int, str, str)->dict
        """
        库存查询-分页查询
             openapi:  /openapi2/stock_query.php
            奇门云网关: wdt.stock.query

        Docs:
            https://open.wangdian.cn/qyb/open/apidoc/doc?path=stock_query.php

        :param datetime start_time: str datetime.strftime("%Y-%m-%d %H:%M:%S"), required
        :param datetime end_time: str datetime.strftime("%Y-%m-%d %H:%M:%S"), required
        :param str warehouse_no: str
        :param str spec_no: str
        :param int page_no: int, required
        :param int page_size: int, required
        :return: dict
        """
        data = dict(list(filter(lambda x: x[1] is not None, dict(
            warehouse_no=warehouse_no,
            spec_no=spec_no,
            start_time=start_time.strftime("%Y-%m-%d %H:%M:%S"),
            end_time=end_time.strftime("%Y-%m-%d %H:%M:%S"),
            page_no=page_no,
            page_size=page_size,
        ).items())))
        return self._post("/openapi2/stock_query.php", data=data)



# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals

import hashlib

import six


def force_bytes(s, encoding='utf-8', strings_only=False, errors='strict'):
    """
    Similar to smart_bytes, except that lazy instances are resolved to
    strings, rather than kept as lazy objects.

    If strings_only is True, don't convert (some) non-string-like objects.
    """
    if isinstance(s, bytes):
        if encoding == 'utf-8':
            return s
        else:
            return s.decode('utf-8', errors).encode(encoding, errors)
    if strings_only and (s is None or isinstance(s, int)):
        return s
    if not isinstance(s, six.string_types):
        try:
            if six.PY3:
                return six.text_type(s).encode(encoding)
            else:
                return bytes(s)
        except UnicodeEncodeError:
            if isinstance(s, Exception):
                # An Exception subclass containing non-ASCII data that doesn't
                # know how to print itself properly. We shouldn't raise a
                # further exception.
                return b' '.join([force_bytes(arg, encoding, strings_only,
                                              errors) for arg in s])
            return six.text_type(s).encode(encoding, errors)
    else:
        return s.encode(encoding, errors)


def calculate_signature(params, appsecret):
    """

    :param dict params: {"sid": "123213", "appkey":"aaaaa", "timestamp": 1527821390 }
    :param str appsecret:
    :return:
    """

    assert 'sid' in params
    assert 'appkey' in params
    assert 'timestamp' in params
    _params = list(params.items())
    _params.sort()
    attr = []
    for key, val in _params:
        bit = "%02d-%s:%04d-%s" % (len(force_bytes(key)), key,
                                   len(force_bytes(val)), val)
        attr.append(bit)

    s = force_bytes(";".join(attr) + appsecret)
    m = hashlib.md5(s)
    return m.hexdigest()


# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
import json
from datetime import datetime
from wangdiantong.api.base import BaseAPIEndpoint


class GoodsAPI(BaseAPIEndpoint):

    def goods_push_platfrom(self, shop_no, platform_id, goods_list):
        """
        Docs: https://open.wangdian.cn/qyb/open/apidoc/doc?path=api_goodsspec_push.php
            OpenApi:   /openapi2/api_goodsspec_push.php
            奇门云网官: method=wdt.api.goodsspec.push
            只支持创建自有平台的平台货品，货品明细一次不能超过2000行
            此接口用不到, 一般来说是系统商品已经建好, 下订单匹配商家编码就有平台货品了

        :param str shop_no: varchar(40), required	店铺编号		店铺编号
        :param int platform_id: int(4), required  平台id
        :param array goods_list[]: Array, required  平台货品列表
            :param int status: int(4), required 状态 0删除 1在架 2下架
            :param str goods_id: varchar(40), required 外部系统货品主键,外部系统货品主键
            :param str goods_no: varchar(40), optional 货品商家编码
            :param str goods_name: varchar(256), optional 货品名称
            :param str spec_id: varchar(40), required 规格ID 外部系统货品规格id
            :param str spec_no: varchar(40), required 规格编码 外部系统规格商家编码
            :param str spec_code: varchar(40), optional 平台规格码 外部系统规格编码
            :param str spec_name: varchar(100), optional 规格名称 外部系统规格名称
            :param str pic_url: varchar(255), optional 图片url 外部系统图片url
            :param decimal price: decimal(19, 4), optional 商品价格
            :param decimal stock_num: decimal(19, 4), optional 平台库存
            :param str cid: varchar(40), optional 平台类目
        :return:


        """
        data = {
            "api_goods_info": json.dumps(
                dict(
                    shop_no=shop_no,
                    platform_id=platform_id,
                    goods_list=goods_list
                )
            )

        }

        return self._post("/openapi2/api_goodsspec_push.php", data=data)


    def query(self, start_time, end_time,
                    spec_no=None, goods_no=None,
                    page_no=0, page_size=40, **kwargs):
        """
        查询货品档案

        Docs: https://open.wangdian.cn/qyb/open/apidoc/doc?path=goods_query.php
            OpenApi:   /openapi2/goods_query.php
            奇门云网官: method=wdt.goods.query

        :param datetime start_time: str datetime.strftime("%Y-%m-%d %H:%M:%S"), required 最后更新时间，开始日期
        :param datetime end_time: str datetime.strftime("%Y-%m-%d %H:%M:%S"), required  最后更新时间，结束日期
        :param int page_no: int(10), required 页号,默认0，从0页开始
        :param int page_size: int(10), required 分页大小（最大不超过40条，默认返回40条）

        :param str spec_no: varchar(40) 商家编码（如果不传时间，则spec_no和goods_no必须传一个）
        :param str goods_no: varchar(4) 货品编号
        :param str brand_no: varchar(32) 品牌编号

        ::kwargs
        :param str class_name: varchar(32) 分类名称
        :param str barcode: varchar(64) 条码

        :return:
        """
        if start_time is None:
            assert goods_no or spec_no

        query = dict(
            start_time=start_time.strftime("%Y-%m-%d %H:%M:%S"),
            end_time=end_time.strftime("%Y-%m-%d %H:%M:%S"),
            page_no=page_no,
            spec_no=spec_no,
            goods_no=goods_no,
            page_size=page_size,
        )
        query.update(**kwargs)
        data = dict(list(filter(lambda x: x[1] is not None, query.items())))
        return self._post("/openapi2/goods_query.php", data=data)

    def suites_query(self, start_time, end_time,
                     suite_no, page_no=0, page_size=40, **kwargs):
        """

        :param datetime start_time: str datetime.strftime("%Y-%m-%d %H:%M:%S"), required 最后更新时间，开始日期
        :param datetime end_time: str datetime.strftime("%Y-%m-%d %H:%M:%S"), required  最后更新时间，结束日期
        :param suite_no: str  required 代表组合装商品所有属性的唯一编码，用于系统组合装商品数据的获取;如果按照组合装商家编码查询，可以不传送开始时间和结束时间
        :param int page_no: int(10), required 页号,默认0，从0页开始
        :param int page_size: int(10), required 分页大小（最大不超过40条，默认返回40条）

        ::kwargs
        :param str class_name: varchar(32) 分类名称
        :param str brand_name: varchar(32) 品牌名称
        :return:

            {
                'total_count': 1,
                'message': '',
                'code': 0,
                'suites': [
                    {
                        'unit_name': '',
                        'barcode_count': '0',
                        'weight': '0.8230',
                        'class_name': '无',
                        'wholesale_price': '0.0000',
                        'member_price': '0.0000',
                        'brand_name': '无',
                        'unit_aux_name': '',
                        'flag_name': '',
                        'short_name': 'xxxx',
                        'barcode': '',
                        'market_price': '0.0000',
                        'suite_name': 'xxxx',
                        'retail_price': '0.0000',
                        'remark': '',
                        'created': '0000-00-00 00:00:00',
                        'suite_no': 'xxxxxx',
                        'modified': '2020-04-20 10:36:11',
                        'prop4': '',
                        'specs_list': [{
                            'fixed_price': '355.0000',
                            'ratio': '0.6906',
                            'goods_name': 'xxxxx',
                            'created': '0000-00-00 00:00:00',
                            'barcode': 'xxxxxx',
                            'modified': '2020-04-20 10:36:11',
                            'num': '1.0000',
                            'spec_name': 'xxxxx',
                            'suite_id': '686',
                            'spec_code': '0',
                            'goods_no': 'xxxxx',
                            'spec_no': 'xxxx',
                            'is_fixed_price': '0'
                        }, {
                            'fixed_price': '1590.0000',
                            'ratio': '0.3094',
                            'goods_name': 'xxxxx',
                            'created': '0000-00-00 00:00:00',
                            'barcode': 'xxxxxxx',
                            'modified': '2020-04-20 10:36:11',
                            'num': '1.0000',
                            'spec_name': 'xxxxx',
                            'suite_id': '686',
                            'spec_code': '0',
                            'goods_no': 'xxxxxx',
                            'spec_no': 'xxxxxxx',
                            'is_fixed_price': '0'
                        }],
                        'prop1': '',
                        'prop2': '',
                        'prop3': '',
                        'suite_id': 'xxxx',
                        'large_split': '0'
                    }
                ]
            }
        """

        if suite_no:
            query = dict(
                page_no=page_no,
                suite_no=suite_no,
                page_size=page_size,
            )
        else:
            query = dict(
                start_time=start_time.strftime("%Y-%m-%d %H:%M:%S"),
                end_time=end_time.strftime("%Y-%m-%d %H:%M:%S"),
                page_no=page_no,
                page_size=page_size,
            )
        query.update(**kwargs)
        data = dict(list(filter(lambda x: x[1] is not None, query.items())))
        return self._post("/openapi2/suites_query.php", data=data)





# -*- coding: utf-8 -*-
import wangdiantong as wdt
from os.path import dirname, abspath, join

from setuptools import setup, find_packages

LIB_DIR = dirname(abspath(__file__))


def long_description():
    with open(join(LIB_DIR, 'README.md')) as readme_file:
        readme = readme_file.read()

    # with open(join(LIB_DIR, 'HISTORY.md')) as history_file:
    #     history = history_file.read()
    # return readme + '\n\n' + history


requirements = ['certifi', 'chardet', 'idna', 'requests', 'urllib3']

test_requirements = ['appnope==0.1.0', 'atomicwrites==1.1.5', 'attrs==18.1.0', 'backports.shutil-get-terminal-size==1.0.0', 'bumpversion==0.5.3', 'cov-core==1.15.0', 'coverage==4.5.1', 'decorator==4.3.0', 'enum34==1.1.6', 'funcsigs==1.0.2', 'ipython-genutils==0.2.0', 'ipython==5.7.0', 'lxml==4.2.1', 'more-itertools==4.2.0', 'namedlist==1.7',
                     'nose-allure-plugin==1.0.5', 'nose-cov==1.6', 'nose==1.3.7', 'pathlib2==2.3.2', 'pexpect==4.5.0', 'pickleshare==0.7.4', 'pluggy==0.6.0', 'prompt-toolkit==1.0.15', 'ptyprocess==0.5.2', 'py==1.5.3', 'pygments==2.2.0', 'pytest-allure-adaptor==1.7.10', 'pytest==3.6.0', 'scandir==1.7', 'simplegeneric==0.8.1', 'six==1.11.0', 'traitlets==4.3.2', 'wcwidth==0.1.7']


setup(
    name='wangdiantong-py',
    packages=find_packages(exclude=['wangdiantong.tests']),
    version=wdt.__version__,
    description="wangdiantong python openapi",
    long_description_content_type="text/markdown",
    long_description=long_description(),
    author=wdt.__author__,
    author_email=wdt.__email__,
    url='https://github.com/AoAoStudio/wangdiantong-py',
    entry_points={
        'console_scripts': [
        ]
    },
    include_package_data=True,
    install_requires=requirements,
    zip_safe=False,
    keywords='wangdiantong',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    test_suite='nose.collector',
    tests_require=test_requirements
)
